import { SvgProportions } from '../models/SvgProportions';
import { PathOptions, Point, RenderOutput } from './../models';
export declare class LinePath {
    /**
     * The main SVG element. You can reuse it if needed.
     */
    protected svgElement: SVGSVGElement;
    /**
     * The path line drawn in the SVG, this will be appended automatically to `svgPath`.
     */
    protected svgPathLine: SVGPathElement;
    /**
     * The div that will contain the svg, this is positionned in absolute relatively to the DOM element `appendTo`,
     * This helps us position the SVG inside the div in absolute too.
     */
    protected containerDiv: HTMLDivElement;
    /**
     * The SVG's defs can contain gradient stops, markers and other stuff. In this case, we'll keep our marker(s)
     * appended to those defs. This lets the developer add his own defs if needed for example.
     */
    protected defs: SVGDefsElement;
    /**
     * The starting element BBox that we get from `getBoundingClientRect()`. This is used to do the calculations
     * needed to draw our path.
     */
    protected startBbox: DOMRect;
    /**
     * The ending element BBox that we get from `getBoundingClientRect()`. This is used to do the calculations
     * needed to draw our path.
     */
    protected endBbox: DOMRect;
    /**
     * The PathOptions supplied to our class when creating a new instance are stored here.
     */
    protected options: PathOptions;
    constructor(options: PathOptions, debug?: boolean);
    /**
     * If you want your path to adapt to the DOM changes, you'll have to call this function, it will recalculate
     * the path and reappend it if needed.
     * @param debug: boolean; Set this to true if you want to add a red box as a background,
     * this can be helpful if you want to see if the SVG element is being correctley drawn without
     * fiddling with the DOM inspector all the time
     * @returns: RenderOutput; Calling this will return the new rendered container, svg, path and defs.
     * It might be useful for you to avoid dealing with async stuff for example.
     */
    render(debug?: boolean): RenderOutput;
    /**
     * Recalculates the positions of the div container, the svg element and the svg path
     */
    recalculate(): void;
    /**
     * Removes the div container and anything appended to it
     */
    release(): void;
    /**
     * Returns an SVG path (or what's supposed to be in attribute `d`)
     * You can extend this function and add your own logic to draw whatever path you'd like.
     * @param endBbox bbox of the end dom element
     * @param startBbox bbox of the start dom element
     * @returns path string
     */
    getPath(): string;
    /**
     * Adds the paths markers to the defs and adds them to the SVG path
     */
    setPathMarkers(): void;
    /**
     * This function is supposed to take points as input and output them as a string that will be set to the `d` attribute of `<path>`.
     * @param points: Point[]; Array of points that you want to write to your SVG
     * @returns The path string ready to be added to the `d` attribute.
     */
    svgPath(points: Point[]): string;
    /**
     * Set the svg attributes for the positionning and width/height
     */
    setSvgAttrs(): void;
    /**
     * Sets the div attributes for the positionning and width/height
     */
    setDivAttrs(): void;
    /**
     * Calculates the SVG width, height, and other key numbers that can then be used to draw the path
     * @returns
     */
    getSVGProportions(): SvgProportions;
}
